sciplot.data package
====================

Submodules
----------

sciplot.data.bars module
------------------------

.. automodule:: sciplot.data.bars
    :members:
    :undoc-members:
    :show-inheritance:

sciplot.data.generic module
---------------------------

.. automodule:: sciplot.data.generic
    :members:
    :undoc-members:
    :show-inheritance:

sciplot.data.images module
--------------------------

.. automodule:: sciplot.data.images
    :members:
    :undoc-members:
    :show-inheritance:

sciplot.data.lines module
-------------------------

.. automodule:: sciplot.data.lines
    :members:
    :undoc-members:
    :show-inheritance:

sciplot.data.polycollections module
-----------------------------------

.. automodule:: sciplot.data.polycollections
    :members:
    :undoc-members:
    :show-inheritance:

sciplot.data.special module
---------------------------

.. automodule:: sciplot.data.special
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: sciplot.data
    :members:
    :undoc-members:
    :show-inheritance:
